# Open163-Downloader
 网易公开课下载器，支持多线程，可分别下载视频及字幕  

## 下载
[Github发布页](https://github.com/JamesHoi/Open163-Downloader/releases)  
[微云下载](https://share.weiyun.com/5uRDiTm)

## 软件使用教程
<img src="https://s1.ax1x.com/2020/03/22/8I1cB4.png" style="zoom:60%" />
可通过以下几种方式下载

### 方法一.通过新版课程链接进行下载
<img src="https://s1.ax1x.com/2020/03/22/8InIc4.png" width = 40% height = 40% />[范例网页](http://open.163.com/newview/movie/courseintro?newurl=%2Fspecial%2Fopencourse%2Fthought.html)

### 方法二.通过旧版课程链接进行下载
<img src="https://s1.ax1x.com/2020/03/22/8IQHxO.png" width = 40% height = 40% />[范例网页](http://open.163.com/special/sp/thought.html)

### 方法三.通过视频链接进行下载
<img src="https://s1.ax1x.com/2020/03/22/8I1Qht.png" width = 40% height = 40% />[范例网页](http://open.163.com/newview/movie/free?pid=M8KB8VE0G&mid=M8KBDR4UL)

### 下载选项
1. 可选择多少个视频同时下载（线程个数）
2. 可选择字幕和影片是否分开
3. 可选择视频画质（如果原视频可以选择）
4. 可分集下载，用逗号隔开  
例如一共有11集，不需要下载第2集和第6集，填1,3-5,7-11  
下载全部填all，下载当前视频填origin  
若填写课程链接默认下载全部，视频链接默认下载当前视频  
